@@ -98,7 +98,7 @@ printf("safe_ujtoj(): <%s>\n", taro);
 
 taro = safe_memcpy(taro, "@1234567890@", 1000);
 taro = safe_ujtoj(taro);
-taro = safe_memcpy(taro, "դդ줳줳ϤϤϤϤϤʤʤʤʤ", 1000);
+/*taro = safe_memcpy(taro, "դդ줳줳ϤϤϤϤϤʤʤʤʤ", 1000);
 printf("mime_ujtoj(): <%s>\n", mime_ujtoj(taro));
 printf("randdata(): <%d>\n", randdata(0,25));
 printf("randdata(): <%d>\n", randdata(0,25));
@@ -106,7 +106,7 @@ printf("randdata(): <%d>\n", randdata(0,25));
 printf("randdata(): <%d>\n", randdata(0,25));
 printf("randdata(): <%d>\n", randdata(0,25));
 printf("randdata(): <%d>\n", randdata(0,25));
-
+*/
 memset(ch8, 0x00, 34);
 in8 = in_bit("01010101", 8);
 ch8 = out_bit(in8, ch8, 8);
@@ -128,6 +128,8 @@ printf("taro 1: <%s>\n", taro);
 ret = rm_char(taro, '0');
 printf("taro 2: <%s>%d\n\n", taro, ret);
 
+printf("count(): <%d>\n", counts("/tmp/hage", 1, 3));
+printf("count(): <%d>\n", counts("/etc/hage", 1, 3));
 
 
 return 0;
