@@ -314,6 +314,8 @@ echo "<option value=PGSQL>PGSQL";
 echo "<option value=TCP>TCP";
 echo "<option value=UDP>UDP";
 echo "<option value=ICMP>ICMP";
+echo "<option value=ICMP2>ICMP2";
+echo "<option value=TRAC>TRAC";
 echo "<option value=SNTP>SNTP";
 echo "<option value=HOST>HOST";
 echo "</select>";
