@@ -212,6 +212,8 @@ echo "ץȥ";
 echo "<select size=1 name=PROTO>";
 echo "<option value=>̤";
 print("<option value=ICMP>ICMP̳ǧ");
+print("<option value=ICMP2>ICMP̳ǧܺ");
+print("<option value=TRAC>ȥ졼ICMP");
 print("<option value=UDP>UDPݡ");
 print("<option value=TCP>TCPݡ");
 print("<option value=URL>URL status");
