@@ -317,6 +317,8 @@ elseif($step1 > 0 && 0 == strcmp($MONITOR, "PORT") && $step2 <= 0){
    print("<tr><td>");
    print("<select size=1 name=PROTO>");
    print("<option value=ICMP>ICMP̳ǧ");
+   print("<option value=ICMP2>ICMP̳ǧܺ");
+   print("<option value=TRAC>TRAC̳ǧ");
    print("<option value=UDP>UDPݡȥå");
    print("<option value=TCP>TCPݡȥå");
    print("<option value=URL>URLơ");
@@ -484,6 +486,22 @@ elseif($step1>0 && $step2>0 && $step3>0 && $step4>0 && $step5<=0){
          print("<INPUT type='hidden' NAME=PORT size='8' value='0'>");
          print("</td></tr>");
          }
+      else if(0 == strcmp($PROTO, "ICMP2")){
+         print("<tr><td>");
+         print("STEP5: ICMP2ݡ0\n");
+         print("</td></tr>");
+         print("<tr><td>");
+         print("<INPUT type='hidden' NAME=PORT size='8' value='0'>");
+         print("</td></tr>");
+         }
+      elseif(0 == strcmp($PROTO, "TRAC")){
+         print("<tr><td>");
+         print("STEP5: TRACݡ0\n");
+         print("</td></tr>");
+         print("<tr><td>");
+         print("<INPUT type='hidden' NAME=PORT size='8' value='0'>");
+         print("</td></tr>");
+         }
       elseif(0 == strcmp($PROTO, "SNTP")){
          print("<tr><td>");
          print("STEP5: NTPݡ123\n");
