@@ -127,6 +127,8 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<select size=1 name=PROTO>";
    echo "<option value=$PROTO selected>$PROTO";
    echo "<option value=ICMP>ICMP";
+   echo "<option value=ICMP2>ICMP2";
+   echo "<option value=TRAC>TRAC";
    echo "<option value=UDP>UDP";
    echo "<option value=TCP>TCP";
    echo "<option value=URL>URL";
