@@ -29,21 +29,33 @@ int stat;
 stat = 0;
 
 if((char *)strcasestr(rec, "_BAT") != NULL){
-   pthread_mutex_lock(&file2_mutex);
+// pthread_mutex_lock(&file2_mutex);
+   safe_pthread_mutex_lock(&file2_mutex);
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: check_alget(1): _BAT(COMAND) (%s)\n", rec);
    #endif
    stat = get_alget(gd.fi.bat_filename, "COMAND");
    pthread_mutex_unlock(&file2_mutex);
    }
+
 if((char *)strcasestr(rec, "_SCA") != NULL){
-   pthread_mutex_lock(&file1_mutex);
+   // listファイルに変更があった場合フラグをたてる
+   safe_pthread_mutex_lock(&file1_mutex);
+   gd.fi.list_stat = 1;
    #ifdef BAT_DEBUG
-   printf("BAT_DEBUG: check_alget(2): _SCA(PORT) (%s)\n", rec);
+   printf("BAT_DEBUG: check_alget(2): _SCA(PORT) flag set (%s)\n", rec);
    #endif
-   stat = get_alget(gd.fi.bat2_filename, "PORT");
    pthread_mutex_unlock(&file1_mutex);
+
+// safe_pthread_mutex_lock(&file1_mutex);
+// #ifdef BAT_DEBUG
+// printf("BAT_DEBUG: check_alget(2): _SCA(PORT) (%s)\n", rec);
+// #endif
+// stat = get_alget(gd.fi.bat2_filename, "PORT");
+// pthread_mutex_unlock(&file1_mutex);
    }
+
+
 if((char *)strcasestr(rec, "_CONF") != NULL){
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: check_alget(3): _CONF (%s)\n", rec);
@@ -56,8 +68,11 @@ if((char *)strcasestr(rec, "_STAT") != NULL){
    #endif
    stat = get_statfile("STAT");
    }
+
+// 以下は現在実装なし
 if((char *)strcasestr(rec, "_CRONFILE") != NULL && gd.cron_onoff == 1){
-   pthread_mutex_lock(&file3_mutex);
+// pthread_mutex_lock(&file3_mutex);
+   safe_pthread_mutex_lock(&file3_mutex);
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: check_alget(5): _CRONFILE (%s)\n", rec);
    #endif
@@ -65,7 +80,8 @@ if((char *)strcasestr(rec, "_CRONFILE") != NULL && gd.cron_onoff == 1){
    pthread_mutex_unlock(&file3_mutex);
    }
 if((char *)strcasestr(rec, "_CRONLIST") != NULL && gd.cron_onoff == 1){
-   pthread_mutex_lock(&file4_mutex);
+// pthread_mutex_lock(&file4_mutex);
+   safe_pthread_mutex_lock(&file4_mutex);
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: check_alget(6): _CRONLIST (%s)\n", rec);
    #endif
