@@ -34,30 +34,29 @@ int fd;
 char * errdata=COM_1;
 int pid;
 int gid;
-int count;
+int count = 0;  // 未使用
 
 fp = NULL;
 
 // for pthread 
-//pthread_mutex_lock(&exec_mutex);
-safe_pthread_mutex_lock(&exec_mutex);
-for(count = 0; count < COM_LEN; count++){
-   if(pids_count[count] != 1){
-      pids_count[count] = 1;
-      break;
-      }
-   if(count >= (COM_LEN - 1)){
-      #ifdef PEXEC_MUTEX_DEBUG
-      printf("PEXEC_MUTEX: execom(): exec command mutex max over!!! wait 3 sec <%d> %s\n", count, com);
-      #endif
-      sleep(1);
-      count = 0;
-      }
-   }
-#ifdef PEXEC_MUTEX_DEBUG
-printf("PEXEC_MUTEX: execom(): exec command mutex no <%d> %s %d\n", count, com, &pids_count);
-#endif
-pthread_mutex_unlock(&exec_mutex);
+//safe_pthread_mutex_lock(&exec_mutex);
+//for(count = 0; count < COM_LEN; count++){
+//   if(pids_count[count] != 1){
+//      pids_count[count] = 1;
+//      break;
+//      }
+//   if(count >= (COM_LEN - 1)){
+//      #ifdef PEXEC_MUTEX_DEBUG
+//      printf("PEXEC_MUTEX: execom(): exec command mutex max over!!! wait 3 sec <%d> %s\n", count, com);
+//      #endif
+//      sleep(1);
+//      count = 0;
+//      }
+//   }
+//#ifdef PEXEC_MUTEX_DEBUG
+//printf("PEXEC_MUTEX: execom(): exec command mutex no <%d> %s %d\n", count, com, &pids_count);
+//#endif
+//pthread_mutex_unlock(&exec_mutex);
 
 
 
@@ -74,13 +73,21 @@ else {
    while(1){
       FD_ZERO(&rfds);
       FD_SET(fd, &rfds);
+
       retval = select(fd + 1, &rfds,  &rfds, NULL, &tv); 
+
       #ifdef PEXEC_DEBUG
       fprintf(stderr, "PEXEC: execom(): SELECT %d\n", retval);
       #endif
+
+
+      // select にエラーがあったか何もおこらなかった TIME OUT & ERROR
       if(retval <= 0){
+
+//       printf("PEXEC: PID=%d TIME OUT & ERROR retval %d (%s: %s) Limit=%d\n",pid, retval, errdata, com, interval);
+
          #ifdef PEXEC_DEBUG
-         printf("PEXEC: execom(): %s%s Kill PID=%d+ Limit=%d\n", errdata, com, pid, interval);
+         printf("PEXEC: err execom(retval %d): %s%s Kill PID=%d+ Limit=%d\n",retval, errdata, com, pid, interval);
          #endif
          buf = safe_sprintf(buf, BUF_MAX,"%s%s Kill PID=%d+ Limit=%d\n",
             errdata,com,pid,interval);
@@ -109,36 +116,46 @@ else {
                   }
                }
 
-            p_pclose(fp, count);
+            p_pclose(fp, pid, count);
 
-            // for pthread 
-    //      pthread_mutex_lock(&exec_mutex);
-            safe_pthread_mutex_lock(&exec_mutex);
-            pids_count[count] = 0;
-            #ifdef PEXEC_MUTEX_DEBUG
-            printf("PEXEC_MUTEX: execom(): exec command mutex no exit <%d> %s\n", count, com);
-            #endif
-            pthread_mutex_unlock(&exec_mutex);
+//            // for pthread 
+//            safe_pthread_mutex_lock(&exec_mutex);
+//            pids_count[count] = 0;
+//            #ifdef PEXEC_MUTEX_DEBUG
+//            printf("PEXEC_MUTEX: execom(): exec command mutex no exit <%d> %s\n", count, com);
+//            #endif
+//            pthread_mutex_unlock(&exec_mutex);
 
             return buf;
             }
          } 
-      if(retval >= 1){
+
+      // select で、時間内にあくしょんがあった。
+      else{
+
+//       printf("PEXEC: PID=%d true retval %d (%s: %s) Limit=%d\n",pid, retval, errdata, com, interval);
+
+         #ifdef PEXEC_DEBUG
+         printf("PEXEC: true execom(retval %d): %s%s Kill PID=%d+ Limit=%d\n",retval, errdata, com, pid, interval);
+         #endif
+
          buf = safe_filefdcat(fd, buf, &stat, BUF_MAX, interval);
-         ret = p_pclose(fp, count);
+         ret = p_pclose(fp, pid, count);
          break;
          }
+
+
+
       }
    }
 
 // for pthread 
-//pthread_mutex_lock(&exec_mutex);
-safe_pthread_mutex_lock(&exec_mutex);
-pids_count[count] = 0;
-#ifdef PEXEC_MUTEX_DEBUG
-printf("PEXEC_MUTEX: execom(): exec command mutex no exit <%d> %s\n", count, com);
-#endif
-pthread_mutex_unlock(&exec_mutex);
+//safe_pthread_mutex_lock(&exec_mutex);
+//pids_count[count] = 0;
+//#ifdef PEXEC_MUTEX_DEBUG
+//printf("PEXEC_MUTEX: execom(): exec command mutex no exit <%d> %s\n", count, com);
+//#endif
+//pthread_mutex_unlock(&exec_mutex);
 
 return buf;
 }
