@@ -45,7 +45,9 @@
 #define SOCK_4 "֤᤮Ƥ⥳ͥ󤬳ΩǤޤǤ  "
 #define SOCK_5 "ͥ˳ΩǤޤǤ  "
 #define SOCK_6 "ƻоݤͥåȥ¸ߤʤǽޤ  "
-#define SOCK_7 "ICMPݡãѥåȤޤݡȤϳƤޤ  "
+#define SOCK_7 "(ICMP_UNREACH)ݡãѥåȤޤݡȤϳƤޤ  "
+#define SOCK_117 "(ICMP_UNREACH_PORT)ݡãѥåȤޤݡȤϳƤޤ  "
+#define SOCK_127 "(ICMP_UNREACH_PORT ICMP_UNREACH) ʳΥѥåȤ򤦤ȤäƤޤޤ "
 #define SOCK_8 "̾Ѵ˽ޤ  "
 #define SOCK_9 "оݤȰۤʤä̾ԤäƤޤ󤫡  "
 #define SOCK_10 "̾褬ॢȤޤNSʤǤ "
@@ -55,6 +57,8 @@
 #define SOCK_14 "ꤵ줿IPۥȤݡֹ椬¸ߤʤǽޤ "
 #define SOCK_15 "select() Ԥǥ顼ȯƤޤ "
 #define SOCK_16 "ͥ󤬥ॢȤޤ "
+#define SOCK_17 "ѥåȤޤǤ "
+#define SOCK_18 "ݡãѥåȤϼޤǤ "
 
 #define URL_1 "URL ֤äƤơɤ200ְʳǤ  "
 #define URL_2 "URL Υǡ뤳ȤޤǤ  "
@@ -76,6 +80,7 @@
 #define STAT_4 "ǡ礭۾Ǥ "
 #define STAT_5 "ơޤ "
 #define STAT_6 "ơԤΤǤ "
+#define STAT_7 "ƻоݤ֤ޤ "
 
 #define COM_1 "¹ԥޥɤॢȤޤ  "
 #define COM_2 "ޥɤ¹ԤǤޤǤ  "
@@ -84,13 +89,39 @@
 
 #define ICMP_1 "RAW socket Ȥˤroot¤ɬפǤ  "
 #define ICMP_2 "ICMP ѥåȤ뤳ȤޤǤ  "
-#define ICMP_3 " ICMP ѥåȤ뤳Ȥޤ  "
+#define ICMP_3 "recv()˽λƤޤ "
 #define ICMP_4 " ICMP ѥåȤäƤޤ  "
 #define ICMP_5 "ICMP RTT ͤäƤޤ  "
 #define ICMP_6 "ICMP RTT ͤǤ  "
+#define ICMP_16 "ICMP RTT 3ʿѤͤǤ "
+#define ICMP_17 "ICMP RTT 3ʿѤͤۤƤޤ "
 #define ICMP_7 "ICMP ѥåȤŪۥȤãǤޤǤȺǸΥ롼äƤޤ  "
 #define ICMP_8 "ICMP ѥåȤTTL0ˤʤꡢѥåȤ˴ޤ"
 #define ICMP_13 "ICMPѥåȤ뤳Ȥޤ "
+#define ICMP_14 "λˤICMPѥåȤ뤳Ȥޤ "
+#define ICMP_15 "ɸIPޤǤѥ롼ֻ֤Ƥޤ "
+#define ICMP_01 "ICMPѥåȤޤ "
+#define ICMP_02 "ѥåԤǥॢȤޤ "
+#define ICMP_03 "RTTॢȤư "
+#define ICMP_04 "ICMP_ECHO 򽦤äƤޤ "
+#define ICMP_05 "ICMP ѥåȰʳ򽦤äƤޤ "
+#define ICMP_06 "IPɥ쥹פޤ "
+
+#define TRACE_1 "RAW socket Ȥˤroot¤ɬפǤ  "
+#define TRACE_2 "tracerouteΥѥåȤ뤳ȤޤǤ  "
+#define TRACE_3 "θ㤷ϥåȼΤѥåȤ֤ޤ "
+#define TRACE_4 "ѥ롼TIMXCEED֤Ƥޤ "
+#define TRACE_5 "ѥ롼TIMXCEED_INTRANS򤫤Ƥޤ "
+#define TRACE_6 "ŪIPѥåȤ֤Ƥޤ "
+#define TRACE_7 "ѥ롼ȤRTTͤͤۤƤޤ TIMXCEED "
+#define TRACE_8 "ѥ롼ȤRTTͤͤۤƤޤ TIMXCEED_INTRANS "
+#define TRACE_9 "ŪIPȤRTTͤͤۤƤޤ "
+#define TRACE_10 "ѥ롼ϰ̲ᤷƤޤ ϩѤޤ "
+#define TRACE_11 "IPΥȥ졼򵭲ޤ󡣥Хåե­Ƥޤ "
+#define TRACE_20 "ŪãƤޤ "
+#define TRACE_21 "ʥݡֹȻפޤ "
+#define TRACE_22 "UDPTRACEƻ뤬߹äƤǽޤ "
+#define TRACE_23 "ICMP ƻ뤬߹äƤǽޤ "
 
 #define MUTEX_1 "Ʊ˼¹Խ֥åοäƤޤ  "
 
@@ -123,14 +154,18 @@
 #define PGSQL_ERR6 "䤤碌˳Կ0Ǥ "
 
 #define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "
+#define MONITOR_ERR_2  "¹Ԥʤƻ°ꤵƤޤ㤨UDPTRACǤΥޥɼ¹Ԥϥåޤ "
 
 #define BLOCK_TEST_1 "ƻ˶ιܤޤޤޤ "
 #define BLOCK_TEST_2 "ƻΥǡ礭 "
 #define BLOCK_TEST_3 "ƻΥǥߥο "
 #define BLOCK_TEST_4 "ƻƬब'#'Ǥ롢̾盧߾֤Ǥ "
-#define BLOCK_TEST_5 " "
-#define BLOCK_TEST_6 "۾ "
+#define BLOCK_TEST_5 "ƻ롢 "
+#define BLOCK_TEST_6 "ƻ롢۾ "
 #define BLOCK_TEST_7 "ƻ˲餫꤬褦Ǥ "
+#define BLOCK_TEST_8 "TEST⡼ "
+#define BLOCK_TEST_15 "մƻ롢 "
+#define BLOCK_TEST_16 "մƻ롢۾ "
 
 #define ERR_MAIL_1 "Ļδְ㤤 "
 #define ERR_MAIL_2 "Υ֥å˳Ƥ줿Ļ֤äƤޤ "
