@@ -149,7 +149,6 @@ if(max > 2){
       else{
          ret = -1;
          }
-
       }
    else{
       ret = -1;
@@ -296,6 +295,8 @@ if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    backdata = safe_sprintf(backdata, BUF_MAX,"Socket generation error: IP=%s Port=%d dgram socket error!",
      ip_addr, port);
    * ret = -1;
+   // socket が作れないばやい
+   close(send_sk);
    return(backdata);
    }
 
@@ -307,6 +308,8 @@ if(bind(send_sk, (void *)&client, sizeof(client)) < 0){
    backdata = safe_sprintf(backdata, BUF_MAX,"IP bind error: IP=%s Port=%d not bind ip or port.",
      ip_addr, port);
    * ret = -1;
+   // bind 出来ないばやい
+   close(send_sk);
    return(backdata);
    }
 
@@ -317,6 +320,7 @@ if(0 == (int)server.sin_addr.s_addr){
    backdata=safe_sprintf(backdata,BUF_MAX,"Illegal Internet Protocol address: %s %d",
      ip_addr, (int)server.sin_addr.s_addr);
    * ret = -1;
+   close(send_sk);
    return backdata;
    }
 server.sin_port = htons(port);
@@ -334,6 +338,7 @@ if((sender_len = sendto(send_sk, (char *)&qdata, (send_len + 1), 0, (void *)&ser
    backdata = safe_sprintf(backdata, BUF_MAX,"Data transmission error: len<%d> ERRNO: %d %s",
      sender_len, errno, strerror(errno));
    * ret = -1;
+   // 送信出来ないばあい
    close(send_sk);
    return(backdata);
    }
@@ -348,26 +353,6 @@ while(1){
    retval = select(send_sk + 1, &select_fd, NULL, NULL, &tv);
 
    // select()に関するエラー、タイムアウトなど
-   if(retval < 0){
-      #ifdef DNS_BUG
-      printf("DNS: scan-dns(1): retval <%d> ERRNO: %d %s\n", retval, errno, strerror(errno));
-      #endif
-      backdata = safe_sprintf(backdata, BUF_MAX,"Network abnormal error: retval <%d> ERRNO: %d %s",
-        retval, errno, strerror(errno));
-      * ret = -1;
-      close(send_sk);
-      return(backdata);
-      }
-   if(retval == 0){
-      #ifdef DNS_BUG
-      printf("DNS: scan-dns(2): retval <%d> ERRNO: %d %s\n", retval, errno, strerror(errno));
-      #endif
-      backdata = safe_sprintf(backdata, BUF_MAX, "Reception time-out error: retval <%d> ERRNO: %d %s",
-        retval, errno, strerror(errno));
-      * ret = -1;
-      close(send_sk);
-      return(backdata);
-      }
    if(retval >= 1){
       adata_len = recvfrom(send_sk, (char *)&adata, 512, 0, NULL, NULL);
       gettimeofday(&tv_vts, NULL);
@@ -378,6 +363,26 @@ while(1){
       close(send_sk);
       break;
       }
+   else if(retval == 0){
+      #ifdef DNS_BUG
+      printf("DNS: scan-dns(2): retval <%d> ERRNO: %d %s\n", retval, errno, strerror(errno));
+      #endif
+      backdata = safe_sprintf(backdata, BUF_MAX, "Reception time-out error: retval <%d> ERRNO: %d %s",
+        retval, errno, strerror(errno));
+      * ret = -1;
+      close(send_sk);
+      return(backdata);
+      }
+   else{
+      #ifdef DNS_BUG
+      printf("DNS: scan-dns(1): retval <%d> ERRNO: %d %s\n", retval, errno, strerror(errno));
+      #endif
+      backdata = safe_sprintf(backdata, BUF_MAX,"Network abnormal error: retval <%d> ERRNO: %d %s",
+        retval, errno, strerror(errno));
+      * ret = -1;
+      close(send_sk);
+      return(backdata);
+      }
    } /* while */
 
 
@@ -387,7 +392,6 @@ while(1){
 //   }
 
 
-
 // 受け取ったデータ数から送信したデータ数を引いた数が0か0以下の場合はエラー
 if(0 >= (adata_len - send_len + 1)){
    #ifdef DNS_BUG
@@ -395,7 +399,6 @@ if(0 >= (adata_len - send_len + 1)){
    #endif
    backdata = safe_sprintf(backdata, BUF_MAX, "recve data size error. send<%d> recv<%d>", send_len, adata_len);
    * ret = 1;
-   close(send_sk);
    return(backdata);
    }
 
@@ -436,7 +439,6 @@ if(ancount <= 0){
    #endif
    backdata = safe_sprintf(backdata, BUF_MAX, "DNS Non-responding error <%d>", ancount);
    * ret = 1;
-   close(send_sk);
    return(backdata);
    }
 
