@@ -40,6 +40,14 @@ if((pd->sb.ch_plai = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
 if((pd->sb.swap_2 = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
 if((pd->sb.scan_all = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
 
+if((pd->db.swap = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.swap1 = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.swap2 = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.server = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.username = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.passwd = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((pd->db.database = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
+
 return 0;
 }
 
@@ -75,11 +83,34 @@ free(pd->sb.ch_com);
 free(pd->sb.ch_plai);
 free(pd->sb.swap_2);
 free(pd->sb.scan_all);
+
+free(pd->db.swap);
+free(pd->db.swap1);
+free(pd->db.swap2);
+free(pd->db.server);
+free(pd->db.username);
+free(pd->db.passwd);
+free(pd->db.database);
+
 return 0;
 }
 
 
 
+int db_malloc_null(private_data_t *pd)
+{
+
+pd->db.swap = null_free(pd->db.swap);
+pd->db.swap1 = null_free(pd->db.swap1);
+pd->db.swap2 = null_free(pd->db.swap2);
+pd->db.server = null_free(pd->db.server);
+pd->db.username = null_free(pd->db.username);
+pd->db.passwd = null_free(pd->db.passwd);
+pd->db.database = null_free(pd->db.database);
+
+return 0;
+}
+
 
 int scan_malloc_null(private_data_t *pd)
 {
@@ -110,6 +141,8 @@ pd->sb.ch_plai = null_free(pd->sb.ch_plai);
 pd->sb.swap_2 = null_free(pd->sb.swap_2);
 pd->sb.scan_all = null_free(pd->sb.scan_all);
 
+db_malloc_null(pd);
+
 return 0;
 }
 
