@@ -18,11 +18,19 @@
 int scan_port(private_data_t *pd)
 {
 int st;
-int ret = -1;
-int inA = 0;
-int inB = 0;
-int out = 1;
-int by = 100; // ICMPのしきい値が1の場合、10msec (0.1秒)
+int ret;
+int inA;
+int inB;
+int out;
+int by;
+
+ret = -1;
+inA = 0;
+inB = 0;
+out = 1;
+by = 100; // ICMPのしきい値が1の場合、10msec (0.1秒)
+// by = 10; // ICMPのしきい値が1の場合、10msec (0.01秒)
+
 
 st = 0;
 
@@ -40,17 +48,47 @@ else if((self_memcmp(pd->sb.ch_prot, "SNTP")) == 0){
       }
    }
 
-else if((self_memcmp(pd->sb.ch_prot, "ICMP")) == 0){
+else if((self_memcmp(pd->sb.ch_prot, "TRAC")) == 0){
 
-   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by); // 1回め
-   usleep(1000000);
-   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by); // 2回め
+   pd->sb.ch_info=scan_traceudpsetopt(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); 
 
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
+else if((self_memcmp(pd->sb.ch_prot, "TRAC2")) == 0){
+
+   pd->sb.ch_info=scan_traceudp2setopt(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); 
+
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+else if((self_memcmp(pd->sb.ch_prot, "ICMP")) == 0){
+
+   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); // 1回め
+   usleep(100000);
+   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); // 2回め
+
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+
+else if((self_memcmp(pd->sb.ch_prot, "ICMP2")) == 0){
+
+   pd->sb.ch_info=scan_icmp2(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); 
+
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+
+
 else if((self_memcmp(pd->sb.ch_prot,"URL")) == 0){
    pd->sb.ch_info=scan_url_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, 0);
    if(0 == (int)strlen(pd->sb.ch_info)){
@@ -219,15 +257,17 @@ else if((self_memcmp(pd->sb.ch_prot, "TCP")) == 0){
       }
    }
 
+
+
+
+
 else if((self_memcmp(pd->sb.ch_prot, "UDP")) == 0){
 
-// info_swap = scan_icmp(pd->sb.ch_host, info_swap, pd->sb.timeout, &inA, by); // 1回め
-   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by); // 1回め
-   usleep(1000000);
-// info_swap = scan_icmp(pd->sb.ch_host, info_swap, pd->sb.timeout, &inA, by); // 2回め
-   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by); // 2回め
+   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by, pd->sb.ch_free3); // 1回め
+   usleep(100000);
+   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by, pd->sb.ch_free3); // 2回め
 
-   pd->sb.ch_info = scan_udp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inB);
+   pd->sb.ch_info = scan_udp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inB, pd->sb.ch_free3);
 
    if(inA == 0 && inB == 0){
       ret = 0;
@@ -238,7 +278,6 @@ else if((self_memcmp(pd->sb.ch_prot, "UDP")) == 0){
       #ifdef SCAN_PORT_DEBUG
       fprintf(stderr,"SCAN_PORT: scan_port(): %s non icmp support or not server\n", pd->sb.ch_host);
       #endif
-//    pd->sb.ch_info = safe_sprintf(pd->sb.ch_info, BUF_MAX, "%s %s. ", pd->sb.ch_host, info_swap);
       pd->sb.ch_info = safe_sprintf(pd->sb.ch_info, BUF_MAX, "%s %s. ", pd->sb.ch_host, "non icmp suppot or not server.");
       }
 
@@ -270,6 +309,8 @@ else if((self_memcmp(pd->sb.ch_prot, "UDP")) == 0){
       }
    }
 
+
+
 else{
    ret = -1;
    pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"not support protocoll.\n",BUF_MAX);
@@ -277,6 +318,13 @@ else{
 
 
 
+
+
+
+// ret は各監視が正常かどうかの監視自体が返したステータス
+// sb.check_statはretと同じになるが、条件による
+
+
 // テストとログモードの処理
 if(0 == self_memcmp(pd->sb.ch_plai, "4")){
    out = 4;
@@ -325,26 +373,37 @@ else if(0 == self_memcmp(pd->sb.ch_plai, "13")){
    ret = -1;
    }
 
+
+
 // check_statの設定 正か逆かで反転する。
 // 監視の正逆の判断 check_stat == 1 はエラー 0は正常
 if(ret < 0){
 
-   if(pd->sb.ch_stat[0] == '0'){
+   if(0 == self_memcmp(pd->sb.ch_stat, "0")){
       pd->sb.check_stat = 1;
       }
-   else if(pd->sb.ch_stat[0] == '1'){
+   else if(0 == self_memcmp(pd->sb.ch_stat, "1")){
       pd->sb.check_stat = 0;
       }
+   // 4は無制限でエラー
+   if(0 == self_memcmp(pd->sb.ch_plai, "4")){
+      pd->sb.check_stat = 1;
+      }
+
    }
 
 if(ret >= 0){
 
-   if(pd->sb.ch_stat[0] == '1'){
+   if(0 == self_memcmp(pd->sb.ch_stat, "1")){
       pd->sb.check_stat = 1;
       }
-   else if(pd->sb.ch_stat[0] == '0'){
+   else if(0 == self_memcmp(pd->sb.ch_stat, "0")){
       pd->sb.check_stat = 0;
       }
+   // 4は無制限でエラー
+   if(0 == self_memcmp(pd->sb.ch_plai, "4")){
+      pd->sb.check_stat = 1;
+      }
    }
 
 return 0;
