@@ -18,19 +18,13 @@ extern global_data_t gd;
 // コマンド監視モード
 char * scan_ssl_command(int port, char * url_data, char * backdata, int timeout, long int cert_lim, int * pst, char * plai)
 {
-char comm[BUF_LEN];
-char * comdata = comm;
+char * comdata;
 char * compath = "/usr/local/zither/bin/scanssl";
 
-memset(comdata, 0x00, BUF_LEN);
+comdata = (char *)calloc(BUF_LEN, sizeof(char));
+
+comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s 2>&1", compath, port, timeout, cert_lim, url_data, gd.di.dns_name);
 
-if((strlen(compath) + 128 + 128 + 128 + strlen(url_data) + 25) < BUF_LEN){
-   sprintf(comdata,"%s -p %d -t %d -c %ld -u %s -d %s 2>&1", compath, port, timeout, cert_lim, url_data, gd.di.dns_name);
-   }
-else{
-   sprintf(comdata,"/bin/true -a data_size_over_err");
-   }
-   
 
 #ifdef SCAN_SSL_DEBUG
 printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s\n", comdata);
@@ -136,7 +130,7 @@ else{
    #endif
    }
 
-
+free(comdata);
 return backdata;
 }
 
