@@ -25,15 +25,15 @@
 
 
 
-int self_set_request(char * backdata, char * url_dom, char * url_pass, int max)
+int self_set_request(char * backdata, char * url_dom, char * url_pass, int max, char * mes)
 {
 int ret;
 ret = 0;
 
 if((strlen(url_dom) + strlen(url_pass) + 128 + 115) < max){
    sprintf(backdata,
-     "HEAD /%s HTTP/1.0\nHost: %s\nUser-Agent: %s(monitorring server)\nPragma: no-cache\nCache-Control: no-cache\r\n\r\n",
-     url_pass, url_dom, VERSION);
+     "%s /%s HTTP/1.0\nHost: %s\nUser-Agent: %s(monitorring server)\nPragma: no-cache\nCache-Control: no-cache\r\n\r\n",
+     mes, url_pass, url_dom, VERSION);
    }
 else{
    sprintf(backdata,
