@@ -31,7 +31,8 @@ pthread_mutex_t exec_mutex;
 pthread_mutex_t fdstat_mutex;
 pthread_mutex_t break_mutex;
 pthread_mutex_t thread_mutex;
-
+pthread_mutex_t trace_mutex;
+pthread_mutex_t traceport_mutex;
 
 // sitar main関数
 int main(int argc, char * argv[])
@@ -56,6 +57,8 @@ pthread_mutex_init(&exec_mutex, NULL);
 pthread_mutex_init(&fdstat_mutex, NULL);
 pthread_mutex_init(&break_mutex, NULL);
 pthread_mutex_init(&thread_mutex, NULL);
+pthread_mutex_init(&trace_mutex, NULL);
+pthread_mutex_init(&traceport_mutex, NULL);
 
 malloc_set();
 set_data();
