@@ -77,6 +77,12 @@
   #define B_MID    64
   // パトロール用  #define B_MID    1240
 
+  // TRACE_LEN
+  // 中継情報を記憶するバッファの数
+  // sitar.conf のTRACE_LENで設定可能
+
+  #define TRACE_LEN   32
+
   // L_LENの値の排他処理での待ち時間
 
   #define SLEEP_TIME 1000000
@@ -169,6 +175,17 @@
         int port2;
         }ip;
 
+     struct trace{
+        int trace_len;
+        char *** trace_data;
+        char ** trace_name;
+        char * uni;
+        }tr;
+
+//     struct udpset{
+//        int * udpport;
+//        }ud;
+
      struct dns_ip{
         char * dns_name;
         char * dns_name2;
