@@ -242,7 +242,7 @@ if(neg >= 0){
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "Zither server connection is lost.", gd.ms.inip_addr[pd->rec.fdno]);
+     "Zither server connection is lost.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
 
