@@ -35,7 +35,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "200 OK get err data", gd.ms.inip_addr[pd->rec.fdno]);
+     "200 OK get err data", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    ret = socket_send(gd.ms.sk[pd->rec.fdno], "200 OK get err data\n", (pd->life.life_int + pd->life.life_los + 15));
@@ -47,7 +47,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
       pd->mail.cc_org = safe_memcpy(pd->mail.cc_org, pd->mail.cc, BUF_LEN);
       pd->mail.in_mailonoff = gd.md.in_mailonoff;
 
-      errdata_tok(pd, gd.ms.inip_addr[pd->rec.fdno]);
+      errdata_tok(pd, (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
 
       }
 
@@ -60,7 +60,7 @@ else{
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "500 NG", gd.ms.inip_addr[pd->rec.fdno]);
+     "500 NG", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
 
