@@ -32,7 +32,7 @@ if(ustat == 0 && astat == 0){
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "get is no members.", gd.ms.inip_addr[pd->rec.fdno]);
+     "get is no members.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    putdata = safe_sprintf(putdata, BUF_MAX, "200 KO \n  %s\n  http://zither.ms-n.com\n  GET is no members\n", CL_VAR);
