@@ -13,9 +13,9 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-extern  MYSQL mysql_buf;
-extern  MYSQL * my_conn;
-extern  MYSQL_RES * my_result;
+// extern  MYSQL mysql_buf;
+// extern  MYSQL * my_conn;
+// extern  MYSQL_RES * my_result;
 
 
 // V6 対応
