@@ -11,9 +11,9 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-extern  MYSQL mysql_buf;
-extern  MYSQL * my_conn;
-extern  MYSQL_RES * my_result;
+//extern  MYSQL mysql_buf;
+//extern  MYSQL * my_conn;
+//extern  MYSQL_RES * my_result;
 
 extern  global_data_t gd;
 
@@ -25,8 +25,8 @@ ret = 0;
 
 if(gd.mysql.stat == 1){
    // mysql に問い合わせ
-   if(mysql_query(&mysql_buf, swap) != 0){ 
-      fprintf(stderr,"mysqlexec_datain(0): といあわせができません %s %s\n", mysql_error(&mysql_buf), swap);
+   if(mysql_query(&gd.mysql.mysql_buf, swap) != 0){ 
+      fprintf(stderr,"mysqlexec_datain(0): といあわせができません %s %s\n", mysql_error(&gd.mysql.mysql_buf), swap);
       ret = -1;
       }
    }
@@ -36,8 +36,8 @@ else{
    fprintf(stderr, "mysqlexec_datain(2): つなぎなおしてみました %s\n", swap);
    if(gd.mysql.stat == 1){
       // mysql に問い合わせ
-      if(mysql_query(&mysql_buf, swap) != 0){ 
-         fprintf(stderr,"mysqlexec_datain(3): やはりといあわせが出来ません %s\n", mysql_error(&mysql_buf));
+      if(mysql_query(&gd.mysql.mysql_buf, swap) != 0){ 
+         fprintf(stderr,"mysqlexec_datain(3): やはりといあわせが出来ません %s\n", mysql_error(&gd.mysql.mysql_buf));
          ret = -1;
          }
       }
