@@ -12,9 +12,9 @@
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-extern  MYSQL mysql_buf;
-extern  MYSQL * my_conn;
-extern  MYSQL_RES * my_result;
+// extern  MYSQL mysql_buf;
+// extern  MYSQL * my_conn;
+// extern  MYSQL_RES * my_result;
 
 extern  global_data_t gd;
 
@@ -27,28 +27,28 @@ ret = 0;
 if(gd.mysql.stat == 1){
 
    // mysql に問い合わせ
-   if(mysql_query(&mysql_buf, swap) != 0){ 
-      fprintf(stderr,"mysqlexec_select(1): 正常な問い合わせができてません %s\n", mysql_error(&mysql_buf));
+   if(mysql_query(&gd.mysql.mysql_buf, swap) != 0){ 
+      fprintf(stderr,"mysqlexec_select(1): 正常な問い合わせができてません %s\n", mysql_error(&gd.mysql.mysql_buf));
       ret = -1;
       return ret;
       }
 
    // mysql 問い合わせの返答を受け取る
-   if((my_result = mysql_store_result(&mysql_buf)) == NULL){
-      fprintf(stderr,"mysqlexec_select(2): といあわせの内容がうけとれません %s\n", mysql_error(&mysql_buf));
+   if((gd.mysql.my_result = mysql_store_result(&gd.mysql.mysql_buf)) == NULL){
+      fprintf(stderr,"mysqlexec_select(2): といあわせの内容がうけとれません %s\n", mysql_error(&gd.mysql.mysql_buf));
       ret = -2;
       return ret;
       }
 
-   ret = mysql_num_rows(my_result);
+   ret = mysql_num_rows(gd.mysql.my_result);
 
    if(ret > 0){
       #ifdef MYSQL_DEBUG
-      fprintf(stderr,"mysqlexec_select(3): 何かひけました %s\n", mysql_error(&mysql_buf));
+      fprintf(stderr,"mysqlexec_select(3): 何かひけました %s\n", mysql_error(&gd.mysql.mysql_buf));
       #endif
       }
    else{
-      fprintf(stderr,"mysqlexec_select(4): 何もひけません %s\n", mysql_error(&mysql_buf));
+      fprintf(stderr,"mysqlexec_select(4): 何もひけません %s\n", mysql_error(&gd.mysql.mysql_buf));
       }
    }
 else{
