@@ -14,9 +14,14 @@
 
 int path_check(char *chA)
 {
-static int bu;
-char ch[30][IP_LEN];
-int count = 0;
+int bu, count, co;
+char ch[34][IP_LEN];
+count = 0;
+
+for(co = 0; co < 34; co++){
+   memset(ch[co], 0x00, IP_LEN);
+   }
+
 char * non="NON";
 char * err_log="ERR_LOG";
 char * con_log="CON_LOG";
@@ -46,6 +51,10 @@ char * on_bcc="ON_BCC";
 char * cron_onoff="CRON_ONOFF";
 char * sig_filename="SIG_FILENAME";
 char * sig_interval="SIG_INTERVAL";
+char * midump_filename ="MIDUMP_FILE";
+char * midump_filename_2 ="MIDUMP_FILE_2";
+char * mid_max ="MID_MAX";
+char * mid_int="MID_INT";
 
 self_memcpy(ch[0], non, IP_LEN);
 self_memcpy(ch[1], err_log, IP_LEN);
@@ -76,10 +85,15 @@ self_memcpy(ch[25], on_bcc, IP_LEN);
 self_memcpy(ch[26], cron_onoff, IP_LEN);
 self_memcpy(ch[27], sig_filename, IP_LEN);
 self_memcpy(ch[28], sig_interval, IP_LEN);
+self_memcpy(ch[29], midump_filename, IP_LEN);
+self_memcpy(ch[30], midump_filename_2, IP_LEN);
+self_memcpy(ch[31], mid_max, IP_LEN);
+self_memcpy(ch[32], mid_int, IP_LEN);
+
 
 bu = 0;
 if(IP_LEN > strlen(chA)){
-   for(count=0; count < 29; count++){
+   for(count=0; count < 33; count++){
       if(0 == self_memcmp(chA, ch[count])){
          bu=count;
          }
