@@ -20,8 +20,8 @@
 #include"jpreturn.h"
 
 #include<libpq-fe.h>
-extern PGconn * conn;
-extern PGresult * res;
+// extern PGconn * conn;
+// extern PGresult * res;
 
 extern global_data_t gd;
 
@@ -31,8 +31,8 @@ int psqlconnect(void)
 int ret;
 ret = 0;
 
-conn = PQconnectdb(gd.pg.postgres_data);
-switch(PQstatus(conn)){
+gd.pg.conn = PQconnectdb(gd.pg.postgres_data);
+switch(PQstatus(gd.pg.conn)){
    case CONNECTION_STARTED:
         fprintf(stderr, "psqlconnect(1): 接続確立待ち postgres.\n");
         break;
@@ -44,8 +44,8 @@ switch(PQstatus(conn)){
         break;
    case CONNECTION_BAD:
         fprintf(stderr, "psqlconnect(4): 接続出来ない postgres.\n");
-        fprintf(stderr, "psqlconnect(5): %s", PQerrorMessage(conn));
-        PQfinish(conn);
+        fprintf(stderr, "psqlconnect(5): %s", PQerrorMessage(gd.pg.conn));
+        PQfinish(gd.pg.conn);
         ret = -1;
         break;
    default:
