@@ -20,8 +20,8 @@
 #include"jpreturn.h"
 
 #include<libpq-fe.h>
-extern  PGconn * conn;
-extern  PGresult * res;
+// extern  PGconn * conn;
+// extern  PGresult * res;
 
 extern  global_data_t gd;
 
@@ -34,18 +34,18 @@ int ret;
 ret = 0;
 
 if(gd.pg.stat == 1){
-   res = PQexec(conn, swap);
-   if(PQresultStatus(res) != PGRES_TUPLES_OK){
+   gd.pg.res = PQexec(gd.pg.conn, swap);
+   if(PQresultStatus(gd.pg.res) != PGRES_TUPLES_OK){
       fprintf(stderr, "psqlexec_select(1): セレクトできてないかも %s\n", swap);
-      PQclear(res);
+      PQclear(gd.pg.res);
       ret = -1;
       }
    else {
       #ifdef POSTGRES_DEBUG
       fprintf(stderr, "POSTGRES_DEBUG: psqlexec_select(2): セレクトできたかも %s\n", swap);
       #endif
-      ret = PQntuples(res);
-      PQclear(res);
+      ret = PQntuples(gd.pg.res);
+      PQclear(gd.pg.res);
       }
    }
 
